@@ -24,9 +24,13 @@ class TVTP_Importer(Excel_Importer):
         "tnr": 1,
         "titel_local": 6,
         "number": 7,
+        "no_of_episodes": 11,
         "deal_type": 15,
         "mandant": 27,
         "est_start": 37,
+        "est_end": 38,
+        "tvod_start": 40,
+        "tvod_end": 41,
         "genre": 19,
         "rating": 20,
         "licensor": 14,
@@ -34,6 +38,7 @@ class TVTP_Importer(Excel_Importer):
         "production_country": 18,
         "quality": 21,
         "tv_network": 32,
+        "studio": 55,
         "vendor_id": 3,
         "vendor_id_itunes": 57,
         "vendor_id_amazon": 59,
@@ -52,13 +57,26 @@ class TVTP_Importer(Excel_Importer):
         "country_ch": 35,
         "right_est": 36,
         "right_tvod": 39,
+        "pf_status_videociety": 43,
+        "pf_status_videobuster": 44,
+        "pf_status_itunes": 45,
+        "pf_status_amazon": 46,
+        "pf_status_maxdome": 47,
+        "pf_status_google": 48,
+        "pf_status_videoload": 49,
+        "pf_status_sky": 50,
+        "first_offer_date": 30,
         "channel_type": 9999,  # wird nicht aus Excel gelesen
     }
 
     tv_episode_map = {
         "titel_local": 10,
         "number": 12,
+        "rating": 20,
         "est_start": 37,
+        "est_end": 38,
+        "tvod_start": 40,
+        "tvod_end": 41,
         "tv_air_date": 31,
         "runtime": 13,
         "vendor_id": 2,
